JwtTokenValidator class
JWT implementation of TokenValidator.
- Implemented types
- Annotations
-
- @Singleton.new()
Constructors
- JwtTokenValidator(JwtConfig _config)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String token) → Map< String, dynamic> ? -
Validate the token. Returns claims map on success, null on failure.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited